@@ -292,7 +292,11 @@ wtap_encaps = {
 	["SLL2"] = 210,
 	["ZWAVE_SERIAL"] = 211,
 	["ETW"] = 212,
-	["ERI_ENB_LOG"] = 213
+	["ERI_ENB_LOG"] = 213,
+	["ZBNCP"] = 214,
+	["USB_2_0_LOW_SPEED"] = 215,
+	["USB_2_0_FULL_SPEED"] = 216,
+	["USB_2_0_HIGH_SPEED"] = 217
 }
 wtap = wtap_encaps -- for bw compatibility
 
@@ -375,7 +379,10 @@ ftypes = {
 	["SYSTEM_ID"] = 42,
 	["STRINGZPAD"] = 43,
 	["FCWWN"] = 44,
-	["STRINGZTRUNC"] = 45
+	["STRINGZTRUNC"] = 45,
+	["OVERFLOW"] = 46,
+	["BADARG"] = 47,
+	["ERROR"] = 48
 }
 
 
@@ -410,20 +417,20 @@ wtap_presence_flags = {
 	["TS"] = 1,  -- time stamp 
 	["CAP_LEN"] = 2,  -- captured length separate from on-the-network length 
 	["INTERFACE_ID"] = 4,  -- interface ID 
+	["SECTION_NUMBER"] = 8,  -- section number 
 }
 
 
 -- Display Bases
 base = {
 	["NONE"] = 0,  -- none
-	["DEC"] = 1,  -- decimal
-	["HEX"] = 2,  -- hexadecimal
-	["OCT"] = 3,  -- octal
-	["DEC_HEX"] = 4,  -- decimal (hexadecimal)
-	["HEX_DEC"] = 5,  -- hexadecimal (decimal)
-	["CUSTOM"] = 6,  -- call custom routine (in ->strings) to format
-	["ASCII"] = 0,  -- shows non-printable ASCII characters as C-style escapes
-	["UNICODE"] = 7,  -- shows non-printable UNICODE characters as \\uXXXX (XXX for now non-printable characters display depends on UI)
+	["DEC"] = 1,  -- decimal [integer, float]
+	["HEX"] = 2,  -- hexadecimal [integer, float]
+	["OCT"] = 3,  -- octal [integer]
+	["DEC_HEX"] = 4,  -- decimal (hexadecimal) [integer]
+	["HEX_DEC"] = 5,  -- hexadecimal (decimal) [integer]
+	["CUSTOM"] = 6,  -- call custom routine to format [integer, float]
+	["EXP"] = 7,  -- exponential [float]
 	["DOT"] = 8,  -- hexadecimal bytes with a period (.) between each byte
 	["DASH"] = 9,  -- hexadecimal bytes with a dash (-) between each byte
 	["COLON"] = 10,  -- hexadecimal bytes with a colon (:) between each byte
@@ -434,12 +441,12 @@ base = {
 	["PT_DCCP"] = 15,  -- DCCP port
 	["PT_SCTP"] = 16,  -- SCTP port
 	["OUI"] = 17,  -- OUI resolution
+	["LOCAL"] = 18,  -- local time in our time zone, with month and day
+	["UTC"] = 19,  -- UTC, with month and day
+	["DOY_UTC"] = 20,  -- UTC, with 1-origin day-of-year
+	["NTP_UTC"] = 21,  -- UTC, with "NULL" when timestamp is all zeros
 	["RANGE_STRING"] = 256,  -- Use the supplied range string to convert the field to text
 	["UNIT_STRING"] = 4096,  -- Add unit text to the field value
-	["LOCAL"] = 1000,  -- local time in our time zone, with month and day
-	["UTC"] = 1001,  -- UTC, with month and day
-	["DOY_UTC"] = 1002,  -- UTC, with 1-origin day-of-year
-	["NTP_UTC"] = 1003,  -- UTC, with "NULL" when timestamp is all zeros
 }
 
 
@@ -527,7 +534,8 @@ ENC_ISO_8601_TIME = 131072
 ENC_ISO_8601_DATE_TIME = 196608
 ENC_RFC_822 = 262144
 ENC_RFC_1123 = 524288
-ENC_STR_TIME_MASK = 983040
+ENC_ISO_8601_DATE_TIME_BASIC = 1048576
+ENC_STR_TIME_MASK = 2031616
 ENC_VARINT_PROTOBUF = 2
 ENC_VARINT_QUIC = 4
 ENC_VARINT_ZIGZAG = 8
@@ -609,15 +617,14 @@ expert = {
 }
 
 
-
 -- menu groups for register_menu
-MENU_ANALYZE_UNSORTED = 0
-MENU_ANALYZE_CONVERSATION = 1
-MENU_STAT_UNSORTED = 2
+MENU_PACKET_ANALYZE_UNSORTED = 0
+MENU_ANALYZE_CONVERSATION_FILTER = 1
+MENU_PACKET_STAT_UNSORTED = 2
 MENU_STAT_GENERIC = 3
-MENU_STAT_CONVERSATION = 4
-MENU_STAT_ENDPOINT = 5
-MENU_STAT_RESPONSE = 6
+MENU_STAT_CONVERSATION_LIST = 4
+MENU_STAT_ENDPOINT_LIST = 5
+MENU_STAT_RESPONSE_TIME = 6
 MENU_STAT_RSERPOOL = 7
 MENU_STAT_TELEPHONY = 8
 MENU_STAT_TELEPHONY_ANSI = 9
@@ -626,6 +633,16 @@ MENU_STAT_TELEPHONY_LTE = 11
 MENU_STAT_TELEPHONY_MTP3 = 12
 MENU_STAT_TELEPHONY_SCTP = 13
 MENU_TOOLS_UNSORTED = 14
+MENU_LOG_ANALYZE_UNSORTED = 15
+MENU_LOG_STAT_UNSORTED = 16
+
+-- Old / deprecated menu groups. These shoudn't be used in new code.
+MENU_ANALYZE_UNSORTED = MENU_PACKET_ANALYZE_UNSORTED
+MENU_ANALYZE_CONVERSATION = MENU_ANALYZE_CONVERSATION_FILTER
+MENU_STAT_CONVERSATION = MENU_STAT_CONVERSATION_LIST
+MENU_STAT_ENDPOINT = MENU_STAT_ENDPOINT_LIST
+MENU_STAT_RESPONSE = MENU_STAT_RESPONSE_TIME
+MENU_STAT_UNSORTED = MENU_PACKET_STAT_UNSORTED
 
 
 -- the possible values for Pinfo's p2p_dir attribute
